@@ -7,18 +7,22 @@ use std::io::{self, BufRead, Write};
 use std::path;
 
 fn get_crate_dir() -> io::Result<path::PathBuf> {
-    Ok(path::PathBuf::from(try!(env::var("CARGO_MANIFEST_DIR")
-        .map_err(|_| io::Error::new(io::ErrorKind::Other, "no CARGO_MANIFEST_DIR")))))
+    Ok(path::PathBuf::from(
+        env::var("CARGO_MANIFEST_DIR").map_err(|_| {
+            io::Error::new(io::ErrorKind::Other, "no CARGO_MANIFEST_DIR")
+        })?,
+    ))
 }
 
-
 fn get_out_dir() -> io::Result<path::PathBuf> {
-    Ok(path::PathBuf::from(try!(env::var("OUT_DIR")
-        .map_err(|_| io::Error::new(io::ErrorKind::Other, "no OUT_DIR")))))
+    Ok(path::PathBuf::from(
+        env::var("OUT_DIR")
+            .map_err(|_| io::Error::new(io::ErrorKind::Other, "no OUT_DIR"))?,
+    ))
 }
 
 fn get_crate_test_path(file_name: &str) -> io::Result<path::PathBuf> {
-    let mut test_path = try!(get_crate_dir());
+    let mut test_path = get_crate_dir()?;
     test_path.push("tests");
     assert!(test_path.is_dir());
     test_path.push(file_name);
@@ -26,7 +30,7 @@ fn get_crate_test_path(file_name: &str) -> io::Result<path::PathBuf> {
 }
 
 fn get_test_path(file_name: &str) -> io::Result<path::PathBuf> {
-    let mut test_path = try!(get_out_dir());
+    let mut test_path = get_out_dir()?;
     assert!(test_path.is_dir());
     test_path.push(file_name);
     Ok(test_path)
@@ -43,32 +47,36 @@ fn generate_sanity_tests_from_afl_seeds() -> io::Result<()> {
     }
     println!("cargo:rerun-if-changed=tests/afl_seeds.rs");
 
-    let test_path = try!(get_test_path("afl_seeds.rs"));
-    let mut test_file = try!(fs::File::create(test_path));
+    let test_path = get_test_path("afl_seeds.rs")?;
+    let mut test_file = fs::File::create(test_path)?;
 
-    try!(writeln!(&mut test_file,
-                  "
+    writeln!(
+        &mut test_file,
+        "
 extern crate cpp_demangle;
 use std::fs;
 use std::io::Read;
-"));
+"
+    )?;
 
-    let mut in_dir = try!(get_crate_dir());
+    let mut in_dir = get_crate_dir()?;
     in_dir.push("in");
     assert!(in_dir.is_dir());
 
-    let entries = try!(fs::read_dir(in_dir));
+    let entries = fs::read_dir(in_dir)?;
 
     for entry in entries {
-        let entry = try!(entry);
+        let entry = entry?;
 
         let path = entry.path();
-        let file_name = try!(path.file_name()
-            .ok_or(io::Error::new(io::ErrorKind::Other,
-                                  "no file name for AFL.rs seed test case")));
+        let file_name = path.file_name().ok_or(io::Error::new(
+            io::ErrorKind::Other,
+            "no file name for AFL.rs seed test case",
+        ))?;
 
-        try!(writeln!(&mut test_file,
-                      r#"
+        writeln!(
+            &mut test_file,
+            r#"
 #[test]
 fn test_afl_seed_{}() {{
     let mut file = fs::File::open("{}").unwrap();
@@ -78,8 +86,9 @@ fn test_afl_seed_{}() {{
     assert!(true, "did not panic when parsing");
 }}
 "#,
-                      file_name.to_string_lossy(),
-                      path.to_string_lossy()));
+            file_name.to_string_lossy(),
+            path.to_string_lossy()
+        )?;
     }
 
     Ok(())
@@ -88,7 +97,7 @@ fn test_afl_seed_{}() {{
 // Ratcheting number that is increased as more libiberty tests start
 // passing. Once they are all passing, this can be removed and we can enable all
 // of them by default.
-const LIBIBERTY_TEST_THRESHOLD: usize = 61;
+const LIBIBERTY_TEST_THRESHOLD: usize = 70;
 
 /// Read `tests/libiberty-demangle-expected`, parse its input mangled symbols,
 /// and expected output demangled symbols, and generate test cases for them.
@@ -101,26 +110,26 @@ const LIBIBERTY_TEST_THRESHOLD: usize = 61;
 fn generate_compatibility_tests_from_libiberty() -> io::Result<()> {
     println!("cargo:rerun-if-changed=tests/libiberty-demangle-expected");
 
-    let test_path = try!(get_test_path("libiberty.rs"));
+    let test_path = get_test_path("libiberty.rs")?;
     let _ = fs::remove_file(&test_path);
-    let mut test_file = try!(fs::File::create(test_path));
+    let mut test_file = fs::File::create(test_path)?;
 
-    try!(writeln!(&mut test_file, "
+    writeln!(
+        &mut test_file,
+        "
 extern crate cpp_demangle;
 extern crate diff;
 use std::fmt::Write;
-"));
+"
+    )?;
 
-    let libiberty_tests = try!(get_crate_test_path("libiberty-demangle-expected"));
-    let libiberty_tests = try!(fs::File::open(libiberty_tests));
+    let libiberty_tests = get_crate_test_path("libiberty-demangle-expected")?;
+    let libiberty_tests = fs::File::open(libiberty_tests)?;
     let libiberty_tests = io::BufReader::new(libiberty_tests);
 
-    let mut lines = libiberty_tests.lines()
-        .filter(|line| {
-            line.as_ref()
-                .map(|l| !l.starts_with('#'))
-                .unwrap_or(true)
-        });
+    let mut lines = libiberty_tests.lines().filter(|line| {
+        line.as_ref().map(|l| !l.starts_with('#')).unwrap_or(true)
+    });
 
     let mut n = 0;
 
@@ -134,8 +143,10 @@ use std::fmt::Write;
         let mangled = match lines.next() {
             Some(Ok(line)) => line,
             None => {
-                return Err(io::Error::new(io::ErrorKind::Other,
-                                          "expected a line with a mangled symbol"))
+                return Err(io::Error::new(
+                    io::ErrorKind::Other,
+                    "expected a line with a mangled symbol",
+                ))
             }
             Some(Err(e)) => return Err(e),
         };
@@ -143,8 +154,10 @@ use std::fmt::Write;
         let demangled = match lines.next() {
             Some(Ok(line)) => line,
             None => {
-                return Err(io::Error::new(io::ErrorKind::Other,
-                                          "expected a line with the demangled symbol"))
+                return Err(io::Error::new(
+                    io::ErrorKind::Other,
+                    "expected a line with the demangled symbol",
+                ))
             }
             Some(Err(e)) => return Err(e),
         };
@@ -156,18 +169,21 @@ use std::fmt::Write;
             match lines.next() {
                 Some(Ok(_)) => {}
                 None => {
-                    return Err(io::Error::new(io::ErrorKind::Other,
-                                              "expected a line with the demangled symbol without parameters"))
+                    return Err(io::Error::new(
+                        io::ErrorKind::Other,
+                        "expected a line with the demangled symbol without parameters",
+                    ))
                 }
                 Some(Err(e)) => return Err(e),
             }
         }
 
         // Skip tests for unsupported languages or options.
-        if options.find("--format=gnu-v3").is_none() ||
-           options.find("--is-v3-ctor").is_some() ||
-           options.find("--is-v3-dtor").is_some() ||
-           options.find("--ret-postfix").is_some() {
+        if options.find("--format=gnu-v3").is_none()
+            || options.find("--is-v3-ctor").is_some()
+            || options.find("--is-v3-dtor").is_some()
+            || options.find("--ret-postfix").is_some()
+        {
             continue;
         }
 
@@ -177,23 +193,28 @@ use std::fmt::Write;
             r###"#[cfg(feature = "run_libiberty_tests")]"###
         };
 
-        try!(writeln!(test_file,
-                      r###"
+        writeln!(
+            test_file,
+            r###"
 {}
 #[test]
 fn test_libiberty_demangle_{}_() {{
     let mangled = br#"{}"#;
-    println!("Parsing mangled symbol: {{}}", String::from_utf8_lossy(mangled));
-
-    let sym = cpp_demangle::Symbol::new(&mangled[..])
-        .expect("should parse mangled symbol");
+    let mangled_str = String::from_utf8_lossy(mangled).into_owned();
+    println!("Parsing mangled symbol: {{}}", mangled_str);
 
     let expected = r#"{}"#;
 
+    let sym = match cpp_demangle::Symbol::new(&mangled[..]) {{
+        Ok(sym) => sym,
+        Err(_) if mangled_str == expected => return,
+        Err(e) => panic!("Should parse mangled symbol {{}}", e),
+    }};
+
     let mut actual = String::new();
     if let Err(e) = write!(&mut actual, "{{}}", sym) {{
         panic!("Error while demangling '{{}}': {{}}",
-               String::from_utf8_lossy(mangled),
+               mangled_str,
                e);
     }}
 
@@ -230,10 +251,11 @@ fn test_libiberty_demangle_{}_() {{
     assert_eq!(expected, actual);
 }}
 "###,
-                      cfg,
-                      n,
-                      mangled.trim(),
-                      demangled.trim()));
+            cfg,
+            n,
+            mangled.trim(),
+            demangled.trim()
+        )?;
 
         n += 1;
     }
@@ -247,6 +269,7 @@ fn main() {
     generate_sanity_tests_from_afl_seeds()
         .expect("should generate sanity tests from AFL.rs seed test cases");
 
-    generate_compatibility_tests_from_libiberty()
-        .expect("should generate compatibility tests from tests/libiberty-demangle-expected");
+    generate_compatibility_tests_from_libiberty().expect(
+        "should generate compatibility tests from tests/libiberty-demangle-expected",
+    );
 }
