@@ -47,6 +47,12 @@ impl<'a> IndexStr<'a> {
         self.as_ref().get(0).cloned()
     }
 
+    /// Peek at the second next byte in this `IndexStr`.
+    #[inline]
+    pub fn peek_second(&self) -> Option<u8> {
+        self.as_ref().get(1).cloned()
+    }
+
     /// Split the string in two at the given index, resulting in the tuple where
     /// the first item has range `[0, idx)`, and the second has range `[idx,
     /// len)`.
@@ -137,9 +143,11 @@ impl<'a, 'b> PartialEq<&'a [u8]> for IndexStr<'b> {
 
 impl<'a> fmt::Debug for IndexStr<'a> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f,
-               "IndexStr {{ idx: {}, string: \"{}\" }}",
-               self.idx,
-               String::from_utf8_lossy(self.as_ref()))
+        write!(
+            f,
+            "IndexStr {{ idx: {}, string: \"{}\" }}",
+            self.idx,
+            String::from_utf8_lossy(self.as_ref())
+        )
     }
 }
